@@ -1,6 +1,6 @@
 var group__pw__buffers =
 [
-    [ "buffers.h", "buffers_8h.html", null ],
+    [ "src/pipewire/buffers.h", "src_2pipewire_2buffers_8h.html", null ],
     [ "pw_buffers", "structpw__buffers.html", [
       [ "mem", "structpw__buffers.html#af915317f3448e471390a13c48c0d873e", null ],
       [ "buffers", "structpw__buffers.html#adf149a809c1ea9c435ae7439391c87ed", null ],
@@ -13,6 +13,7 @@ var group__pw__buffers =
     [ "PW_BUFFERS_FLAG_DYNAMIC", "group__pw__buffers.html#gacb6d3cf39ad33726f3a034ae846c4751", null ],
     [ "PW_BUFFERS_FLAG_SHARED_MEM", "group__pw__buffers.html#ga9c3b4ae5b1b248c35220d86240706a31", null ],
     [ "PW_BUFFERS_FLAG_IN_PRIORITY", "group__pw__buffers.html#ga614b706400e47939c545f56c67f276fa", null ],
+    [ "PW_BUFFERS_FLAG_ASYNC", "group__pw__buffers.html#gaaf0bc5048a4612b03cbc5dfb1ef23a90", null ],
     [ "pw_buffers_negotiate", "group__pw__buffers.html#ga096d7e73ff412f6c49fce1a8a6d99733", null ],
     [ "pw_buffers_clear", "group__pw__buffers.html#ga7701d99e8558482b0c87d2e552b1cd10", null ]
 ];
\ No newline at end of file
